Coverage for /home/ken/src/shared/avendesora/avendesora/editors.py: 0%

# Coverage for /home/ken/src/shared/avendesora/avendesora/editors.py : 0%

## 20 statements 0 run 20 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 | # Avendesora Password Generator Preferences # # Copyright (C) 2016 Kenneth S. Kundert # License {{{1 # This program is free software: you can redistribute it and/or modify # it under the terms of the GNU General Public License as published by # the Free Software Foundation, either version 3 of the License, or # (at your option) any later version. # # This program is distributed in the hope that it will be useful, # but WITHOUT ANY WARRANTY; without even the implied warranty of # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the # GNU General Public License for more details. # # You should have received a copy of the GNU General Public License # along with this program. If not, see http://www.gnu.org/licenses/. # Imports {{{1 from .config import get_setting, add_setting from shlib import Run from inform import log, Error # Editor base class {{{1 class Editor(object): pass # GenericEditor class {{{1 class GenericEditor(Editor): NAME = 'generic' @classmethod def open_and_search(cls, filepath, account = None): args = { 'filepath': filepath, 'account': account, 'section': '{' '{' '{' '1', } try: editor_setting = 'edit_account' if account else 'edit_template' cmd = get_setting(editor_setting) cmd = [e.format(**args) for e in cmd] log("running '%s'." % ' '.join(cmd)) Run(cmd, 'soeW') except OSError as err: raise Error(os_error(err)) except KeyError as err: raise Error('invalid field: %s.' % err, culprit=editor_setting)